==> baloo-4.13.3.tgz: lib/cmake/Baloo/BalooTargetsWithPrefix-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "baloocore" for configuration "Release"
set_property(TARGET baloocore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(baloocore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "qjson;KDE4__kdecore"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libbaloocore.so.1.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS baloocore )
list(APPEND _IMPORT_CHECK_FILES_FOR_baloocore "/usr/local/lib/libbaloocore.so.1.0" )

# Import target "balooxapian" for configuration "Release"
set_property(TARGET balooxapian APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(balooxapian PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "qjson;KDE4__kdecore;baloocore"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libbalooxapian.so.1.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS balooxapian )
list(APPEND _IMPORT_CHECK_FILES_FOR_balooxapian "/usr/local/lib/libbalooxapian.so.1.0" )

# Import target "baloopim" for configuration "Release"
set_property(TARGET baloopim APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(baloopim PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore;qjson"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libbaloopim.so.1.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS baloopim )
list(APPEND _IMPORT_CHECK_FILES_FOR_baloopim "/usr/local/lib/libbaloopim.so.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> baloo-4.14.3p3.tgz: lib/cmake/Baloo/BalooTargetsWithPrefix-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "baloocore" for configuration "Release"
set_property(TARGET baloocore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(baloocore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "qjson;KDE4__kdecore"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libbaloocore.so.2.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS baloocore )
list(APPEND _IMPORT_CHECK_FILES_FOR_baloocore "/usr/local/lib/libbaloocore.so.2.0" )

# Import target "balooxapian" for configuration "Release"
set_property(TARGET balooxapian APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(balooxapian PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "qjson;KDE4__kdecore;baloocore"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libbalooxapian.so.2.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS balooxapian )
list(APPEND _IMPORT_CHECK_FILES_FOR_balooxapian "/usr/local/lib/libbalooxapian.so.2.0" )

# Import target "baloopim" for configuration "Release"
set_property(TARGET baloopim APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(baloopim PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore;qjson"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libbaloopim.so.2.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS baloopim )
list(APPEND _IMPORT_CHECK_FILES_FOR_baloopim "/usr/local/lib/libbaloopim.so.2.0" )

# Import target "balooqueryparser" for configuration "Release"
set_property(TARGET balooqueryparser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(balooqueryparser PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore;baloocore"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libbalooqueryparser.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS balooqueryparser )
list(APPEND _IMPORT_CHECK_FILES_FOR_balooqueryparser "/usr/local/lib/libbalooqueryparser.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
